Changelog
=========

1.1.0 (2022-01-21)
------------------
* Vamped up styles conform `DvG_Arduino_lock-in_amp v2.0` project
* Added hover effects
* Added SS_GROUP_RECT, SS_HOVER & SS_TABS
* Added PyQtGraph color definitions

1.0.0 (2020-08-11)
------------------
* First release on PyPI
